@@ -1,4 +1,5 @@
 from datetime import datetime
+from igloo import _Undefined
 
 
 def get_from_dict(d, keys):
@@ -16,8 +17,10 @@ def parse_arg(arg_name, arg_value, is_enum=False):
 
 
 def get_representation(arg_value, is_enum=False):
-    if arg_value is None:
+    if isinstance(arg_value, _Undefined):
         return ""
+    elif arg_value is None:
+        return "null"
     elif isinstance(arg_value, dict):
         parsed_items = []
         for key, value in arg_value.items():
